@@ -1,6 +1,6 @@
 /* exif-format.c
  *
- * Copyright (C) 2001 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright  2001 Lutz Mller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,30 +17,13 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <config.h>
+
+#include "config.h"
 #include "exif-format.h"
+#include "i18n.h"
 
 #include <stdlib.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
 static struct {
         ExifFormat format;
 	const char *name;
@@ -51,8 +34,12 @@ static struct {
         {EXIF_FORMAT_SHORT,     "Short",     2},
         {EXIF_FORMAT_LONG,      "Long",      4},
         {EXIF_FORMAT_RATIONAL,  "Rational",  8},
-        {EXIF_FORMAT_SLONG,     "SShort",    4},
+	{EXIF_FORMAT_SBYTE,     "SByte",     1},
+	{EXIF_FORMAT_SSHORT,    "SShort",    2},
+        {EXIF_FORMAT_SLONG,     "SLong",     4},
         {EXIF_FORMAT_SRATIONAL, "SRational", 8},
+	{EXIF_FORMAT_FLOAT,     "Float",     4},
+	{EXIF_FORMAT_DOUBLE,    "Double",    8},
         {EXIF_FORMAT_UNDEFINED, N_("Undefined"), 1},
         {0, NULL, 0}
 };
@@ -62,7 +49,8 @@ exif_format_get_name (ExifFormat format)
 {
 	unsigned int i;
 
-	bindtextdomain (PACKAGE, LIBEXIF_LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	bindtextdomain (GETTEXT_PACKAGE, LIBEXIF_LOCALEDIR);
 
 	for (i = 0; ExifFormatTable[i].name; i++)
 		if (ExifFormatTable[i].format == format)
