@@ -1,6 +1,6 @@
 /* exif-utils.h
  *
- * Copyright (C) 2001 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright  2001 Lutz Mller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,14 +26,19 @@ extern "C" {
 #endif /* __cplusplus */
 
 #include <libexif/exif-byte-order.h>
+#include <libexif/_stdint.h>
 
+
+/* If these definitions don't work for you, please let us fix the 
+ * macro generating _stdint.h */
+	
 typedef char		ExifByte;          /* 1 byte  */
 typedef char *		ExifAscii;
-typedef unsigned short	ExifShort;         /* 2 bytes */
-typedef unsigned long	ExifLong;          /* 4 bytes */
+typedef uint16_t	ExifShort;         /* 2 bytes */
+typedef uint32_t	ExifLong;          /* 4 bytes */
 typedef struct {ExifLong numerator; ExifLong denominator;} ExifRational;
 typedef char		ExifUndefined;     /* 1 byte  */
-typedef signed long	ExifSLong;         /* 4 bytes */
+typedef int32_t		ExifSLong;         /* 4 bytes */
 typedef struct {ExifSLong numerator; ExifSLong denominator;} ExifSRational;
 
 
@@ -54,6 +59,12 @@ void exif_set_rational  (unsigned char *b, ExifByteOrder order,
 void exif_set_srational (unsigned char *b, ExifByteOrder order,
 			 ExifSRational value);
 
+#undef  MIN
+#define MIN(a, b)  (((a) < (b)) ? (a) : (b))
+
+/* For compatibility with older versions */
+#define EXIF_TAG_SUBSEC_TIME EXIF_TAG_SUB_SEC_TIME
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
